@@ -89,7 +89,7 @@ def parse_args(args):
     parser.add_argument(
         "--ubi-manifest-url",
         action="store",
-        required=False,  # TODO change to True, when we move to ubi-manifest approach only, without fallback to legacy code path
+        required=True,
         help="URL of ubi-manifest service",
     )
 
@@ -112,10 +112,14 @@ def parse_args(args):
     return parser.parse_args(args), auth
 
 
+FOREIGN_LOGGERS = ("pubtools.pulplib", "fastpurge", "ubiconfig")
+
+
 def main(args):
     logging.basicConfig(format=DEFAULT_LOG_FMT, datefmt=DEFAULT_DATE_FMT)
-    logging.getLogger("pubtools.pulplib").setLevel(logging.INFO)
-    logging.getLogger("fastpurge").setLevel(logging.INFO)
+    for logger in FOREIGN_LOGGERS:
+        logging.getLogger(logger).setLevel(logging.INFO)
+
     opts, auth = parse_args(args)
 
     ubipop.UbiPopulate(
